SystemOrganization addCategory: 'OrbeonBPMRuntime'!

!BpmSubProcessDefinition methodsFor: '*orbeonBPMRuntime' stamp: 'BrunoBB 11/29/2015 17:29'!
getProcessInstanceClass

	^BpmSubProcessInstance! !

BpmObject subclass: #BpmArtifactInstance
	instanceVariableNames: 'definition id process inTransitions outTransitions creationTime'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmArtifactInstance subclass: #BpmActivityInstance
	instanceVariableNames: 'loopCounter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmActivityInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:53'!
loopCounter
	^loopCounter! !

!BpmActivityInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 12:53'!
loopCounter: newValue
	loopCounter := newValue! !

BpmActivityInstance subclass: #BpmGatewayInstance
	instanceVariableNames: 'isClosed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmGatewayInstance subclass: #BpmComplexGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmComplexGateway commentStamp: 'BrunoBB 11/24/2015 13:13' prior: 0!
Splitting

It is similar to an Inclusive Gateway. The difference lies in that it uses a single outgoing assignment within the Gateway instead of a set of conditions over the outgoing paths. The result is the same in the sense that one or more outgoing paths will be activated.

In general, one assignment has two parts: a condition and an action. When an assignment is executed, its condition is evaluated and if it is true, the action is performed; this action can be the updating a property of the process or a Data Object. In the case of a Complex Gateway, the outgoing assignment may refer to process data or its Data Objects and the status of its incoming paths (e.g. if the flow will come from a certain path in a certain process instance). For example, an outgoing assignment may evaluate process data and then select different sets of outgoing paths depending on the results of the evaluation. However, the outgoing assignment should ensure that at least one path will be chosen.

Merging

In this case, an incoming assignment is used when the flow reaches the Gateway. The condition may refer to the same data as in the Splitting behavior of the Complex Gateway (process data, Data Objects, etc.). If the condition evaluates to false, nothing happens except for the fact that the flow is stopped in the Gateway. If it evaluates to true, the action could be to let the flow continue or stop it.

Since the use of the Complex Gateway to merge paths can vary depending on the purpose for which it is used, modelers are recommended to use text annotations to inform the diagram readers about the behavior being assigned to the Gateway.

An example of use would be the discriminator pattern. In this pattern, there are two or more parallel tasks which are merged in a Complex Gateway. When one of the activities is completed, the following tasks can be started. It doesnt matter which activity is completed first. The other tasks are completed normally but they wont affect the process flow, that is to say, new instances of the following tasks will not be generated.!

!BpmComplexGateway methodsFor: 'other' stamp: 'BrunoBB 11/23/2015 13:39'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"! !

BpmGatewayInstance subclass: #BpmEventBasedGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmEventBasedGateway commentStamp: 'BrunoBB 11/24/2015 13:13' prior: 0!
Splitting

This type of Gateway requires the use of one or more catching Intermediate Events. The valid types of events are as follows:
    Message
    Timer
    Conditional
    Signal

Receive tasks can be used instead of Message events, but they can't be mixed. 
It should be pointed out that if none of the events specified occur, the process will be stuck. Therefore, a Timer event is recommended as an alternative.

Merging

It works in the same way as the Exclusive Gateway.
(It merges the flow without making any synchronizations)!

BpmGatewayInstance subclass: #BpmExclusiveEventBasedGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmGatewayInstance subclass: #BpmExclusiveGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmExclusiveGateway commentStamp: 'BrunoBB 11/24/2015 13:13' prior: 0!
Splitting

This type of Gateway divides the flow into two or more paths but the process flow will go down only one of these paths. Conditions are expressed as Gateway attributes and can be expressed in natural language or as formal expressions. The selection of the path to follow will be based on the evaluation of the conditions set for each path. They are evaluated one at a time, in the order in which they were defined in the Gateway (which doesn't mean that their corresponding paths are evaluated as displayed in the diagram) and the path corresponding to the first condition that evaluates to true will be selected. If none of the conditions is true, the process will be stuck in the Gateway. In this case, the use of default paths is suggested.


Merging

It merges the flow without making any synchronizations.!

!BpmExclusiveGateway methodsFor: 'other' stamp: 'BrunoBB 11/26/2015 14:17'!
evaluateOutgoingTransitionsOn: aBpmProcessInstance
	"The receiver is isSplitting and only one of all out going transition is going to be instantiated based on the evaluation of the condition"
	| nextTransitionDef |

	self getOutTrasitionDefinitions do: [:trDefinition | 
		(nextTransitionDef isNil and: [trDefinition evaluateConditionIn: aBpmProcessInstance])
		ifTrue: [nextTransitionDef := trDefinition].
	].

	nextTransitionDef 
	ifNotNil: [aBpmProcessInstance createNewTransition: nextTransitionDef from: self].! !

!BpmExclusiveGateway methodsFor: 'other' stamp: 'BrunoBB 11/28/2015 16:49'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"

	isClosed ifTrue: [^self]. "a transition has already triggered the receiver so there is nothing to do"

	self isSplitting 
	ifTrue: [aBpmProcessInstance finalizeGateway: self.
				self evaluateOutgoingTransitionsOn: aBpmProcessInstance].

	isClosed := true.

	self isMerging 
	ifTrue: [aBpmProcessInstance finalizeGateway: self.
				aBpmProcessInstance generateNextTransitionsFrom: self].! !

!BpmGatewayInstance methodsFor: 'other' stamp: 'BrunoBB 11/24/2015 13:14'!
initialize

	super initialize.

	isClosed := false! !

!BpmGatewayInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/24/2015 13:13'!
isClosed
	^isClosed! !

!BpmGatewayInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/24/2015 13:13'!
isClosed: newValue
	isClosed := newValue! !

!BpmGatewayInstance methodsFor: 'other' stamp: 'BrunoBB 11/23/2015 17:02'!
isMerging
	"Answer whether or not the receiver is merging the process path"

	^definition isMerging! !

!BpmGatewayInstance methodsFor: 'other' stamp: 'BrunoBB 11/23/2015 17:02'!
isSplitting
	"Answer whether or not the receiver is splitting the process path"

	^definition isSplitting! !

!BpmGatewayInstance methodsFor: 'other' stamp: 'BrunoBB 11/20/2015 12:48'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"! !

BpmGatewayInstance subclass: #BpmInclusiveGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmInclusiveGateway commentStamp: 'BrunoBB 11/24/2015 13:13' prior: 0!
Splitting

Its behavior is similar to the Exclusive Gateway in the sense that it allows for the creation of multiple alternative paths based on conditions imposed on those paths. The difference lies in that more than one path can be chosen, that is, all those whose corresponding conditions evaluate to true. In this case, the use of default paths is recommended in order to prevent the process from getting stuck in any situation.

Merging

It works similarly to a Parallel Gateway merging in the sense that it synchronizes all incoming paths. Unlike the Parallel Gateway, it only synchronizes those paths that actually reach the Gateway, which are not necessarily all the incoming paths in the diagram; this could be specific to each process instance.!

!BpmInclusiveGateway methodsFor: 'other' stamp: 'BrunoBB 11/23/2015 13:39'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"! !

BpmGatewayInstance subclass: #BpmParallelEventBasedGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmGatewayInstance subclass: #BpmParallelGateway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmParallelGateway commentStamp: 'BrunoBB 11/24/2015 13:13' prior: 0!
Splitting

It simply divides the flow in two or more parallel paths. No conditions are evaluated.

Merging 

It synchronizes all the paths that arrive to the Gateway!

!BpmParallelGateway methodsFor: 'other' stamp: 'BrunoBB 11/23/2015 13:39'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"! !

BpmActivityInstance subclass: #BpmSubProcessTaskInstance
	instanceVariableNames: 'processInstance'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmSubProcessTaskInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 13:06'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"

	processInstance := definition createProcessInstance: nil.

	processInstance definition addProcessInstance: processInstance.

	processInstance triggerStartEvent;
		creatorTask: self.

	aBpmProcessInstance addSubProcess: processInstance "here also set the parent process"! !

!BpmSubProcessTaskInstance methodsFor: 'Accessing' stamp: 'BrunoBB 12/01/2015 11:52'!
processInstance
	^processInstance! !

!BpmSubProcessTaskInstance methodsFor: 'Updating' stamp: 'BrunoBB 12/01/2015 11:52'!
processInstance: newValue
	processInstance := newValue! !

BpmActivityInstance subclass: #BpmTaskInstance
	instanceVariableNames: 'rolesWhoWorked'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmTaskInstance commentStamp: 'BrunoBB 11/01/2015 12:52' prior: 0!
rolesWhoWorked - a collection to support multiple roles working on the same task. Each time role work finish a part of the task --> "finish" it's task and that roles is added to this collection.!

BpmTaskInstance subclass: #BpmOrbeonTaskInstance
	instanceVariableNames: 'formInstance'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmOrbeonTaskInstance methodsFor: 'Accessing' stamp: 'BrunoBB 10/31/2015 10:55'!
formInstance
	^formInstance! !

!BpmOrbeonTaskInstance methodsFor: 'Updating' stamp: 'BrunoBB 10/31/2015 10:55'!
formInstance: newValue
	formInstance := newValue! !

!BpmOrbeonTaskInstance methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 09:33'!
getValueOfFormField: fieldName
	"Answer the value of the field named <fieldName>"

	^formInstance valueAt: fieldName! !

!BpmOrbeonTaskInstance methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 12:20'!
hasFieldNamed: aSymbol
	"Answer whether or not the receiver has a field named <aSymbol>"

	^formInstance hasFieldNamed: aSymbol! !

!BpmOrbeonTaskInstance methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 09:32'!
hasForm

	^true! !

BpmTaskInstance subclass: #BpmSeasideTaskInstance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmTaskInstance methodsFor: 'other' stamp: 'BrunoBB 11/01/2015 10:39'!
addWorkedRole: aBpmRole
	"The receiver add a role <aBpmRole> who has worked and finish it's part of the task"

	^rolesWhoWorked add: aBpmRole! !

!BpmTaskInstance methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 09:56'!
asAssignmentFor: aBpmRole in: aBpmRunningTasksMatrix
	"The receiver answer a task assignment for a <BpmRole> based on it self"

	^(BpmTaskAssignment newFor: process task: self in: aBpmRunningTasksMatrix)
			roleName: aBpmRole name;
			yourself! !

!BpmTaskInstance methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:29'!
finalize

	^process finalizeTask: self! !

!BpmTaskInstance methodsFor: 'other' stamp: 'BrunoBB 11/01/2015 10:38'!
initialize

	super initialize.

	rolesWhoWorked := OrderedCollection new.! !

!BpmTaskInstance methodsFor: 'other' stamp: 'BrunoBB 11/16/2015 17:33'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"

	^aBpmProcessInstance addActivityToPerform: self! !

!BpmTaskInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 10:36'!
rolesWhoWorked
	^rolesWhoWorked! !

!BpmTaskInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 10:36'!
rolesWhoWorked: newValue
	rolesWhoWorked := newValue! !

!BpmArtifactInstance class methodsFor: 'other' stamp: 'BrunoBB 11/13/2015 10:46'!
definition: aBpmArtifactDefinition

	^super new initialize
		definition: aBpmArtifactDefinition;
		yourself! !

!BpmArtifactInstance class methodsFor: 'other' stamp: 'BrunoBB 11/13/2015 10:46'!
process: aBpmProcessInstance definition: aBpmArtifactDefinition

	^(self definition: aBpmArtifactDefinition)
		process: aBpmProcessInstance;
		yourself! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/16/2015 18:08'!
addIncommingTransition: aBpmTransitionInstance

	^inTransitions add: aBpmTransitionInstance! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/16/2015 18:08'!
addOutgoingTransition: aBpmTransitionInstance

	^outTransitions add: aBpmTransitionInstance! !

!BpmArtifactInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/12/2015 11:08'!
creationTime
	^creationTime! !

!BpmArtifactInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/12/2015 11:08'!
creationTime: newValue
	creationTime := newValue! !

!BpmArtifactInstance methodsFor: 'Accessing' stamp: 'BrunoBB 10/27/2015 14:08'!
definition
	^definition! !

!BpmArtifactInstance methodsFor: 'Updating' stamp: 'BrunoBB 10/27/2015 14:08'!
definition: newValue
	definition := newValue! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:29'!
finalize

	^self! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/22/2015 17:18'!
getDefinitionName
	"Answer the name of the receiver's artifact definition as it was defined in the Process Modeler (Bizagi)"

	^definition name! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/12/2015 11:17'!
getInTrasitionDefinitions

	^definition inTransitions! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/20/2015 11:39'!
getOutTrasitionDefinitions
	"The receiver answer a collection of the next transitions as defined in it's definition"

	^definition outTransitions! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 12/03/2015 13:43'!
getRoles
	"Answer a collection of the granted roles of the receiver"

	^definition roles! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 12:21'!
hasFieldNamed: aSymbol
	"Answer whether or not the receiver has a field named <aSymbol>"

	^false! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 09:32'!
hasForm

	^false! !

!BpmArtifactInstance methodsFor: 'Accessing' stamp: 'BrunoBB 10/27/2015 14:08'!
id
	^id! !

!BpmArtifactInstance methodsFor: 'Updating' stamp: 'BrunoBB 10/27/2015 14:08'!
id: newValue
	id := newValue! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/12/2015 11:09'!
initialize

	super initialize.

	creationTime := TimeStamp now.
	inTransitions := OrderedCollection new.
	outTransitions := OrderedCollection new.! !

!BpmArtifactInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:57'!
inTransitions
	^inTransitions! !

!BpmArtifactInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 12:57'!
inTransitions: newValue
	inTransitions := newValue! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 15:11'!
isEndEvent

	^definition isEndEvent! !

!BpmArtifactInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:57'!
outTransitions
	^outTransitions! !

!BpmArtifactInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 12:57'!
outTransitions: newValue
	outTransitions := newValue! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/16/2015 17:33'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/28/2015 14:42'!
printOn: aStream

	super printOn: aStream.

	aStream nextPutAll: ' (', self printOnType, ') [', self getDefinitionName, ']'.! !

!BpmArtifactInstance methodsFor: 'other' stamp: 'BrunoBB 11/28/2015 14:41'!
printOnType

	^definition printOnType! !

!BpmArtifactInstance methodsFor: 'Accessing' stamp: 'BrunoBB 10/27/2015 14:08'!
process
	^process! !

!BpmArtifactInstance methodsFor: 'Updating' stamp: 'BrunoBB 10/27/2015 14:08'!
process: newValue
	process := newValue! !

BpmArtifactInstance subclass: #BpmEventInstance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmEventInstance subclass: #BpmEndEventInstance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmEndEventInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:03'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"

	aBpmProcessInstance finalizeWith: self! !

!BpmEventInstance methodsFor: 'other' stamp: 'BrunoBB 11/28/2015 16:53'!
performInitializationOn: aBpmProcessInstance
	"The receiver perform the creation operation in the process instance <aBpmProcessInstance>.
	This operatoin initialize the receiver inside the process <aBpmProcessInstance>"! !

BpmEventInstance subclass: #BpmIntermediateEventInstance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmEventInstance subclass: #BpmStartEventInstance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmObject subclass: #BpmCodeEvaluationResult
	instanceVariableNames: 'result exception conditionString'
	classVariableNames: 'FailedEvalCache'
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmCodeEvaluationResult class methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 10:29'!
exception: anException

	^super new initialize
		exception: anException;
		result: false;
		yourself! !

!BpmCodeEvaluationResult class methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 11:23'!
failedEvaluationCache

	FailedEvalCache ifNil: [FailedEvalCache := OrderedCollection new].

	^FailedEvalCache! !

!BpmCodeEvaluationResult class methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 10:29'!
result: aBoolean

	^super new initialize
		result: aBoolean;
		yourself! !

!BpmCodeEvaluationResult methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 12:19'!
addToCache

	^self class failedEvaluationCache add: self! !

!BpmCodeEvaluationResult methodsFor: 'Accessing' stamp: 'BrunoBB 11/25/2015 10:28'!
exception
	^exception! !

!BpmCodeEvaluationResult methodsFor: 'Updating' stamp: 'BrunoBB 11/25/2015 10:39'!
exception: newValue
   "Modify the value of the instance variable 'exception'."

	exception := newValue.
	result := false.! !

!BpmCodeEvaluationResult methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 10:29'!
hasException

	^exception notNil! !

!BpmCodeEvaluationResult methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 10:29'!
hasNoException

	^exception isNil! !

!BpmCodeEvaluationResult methodsFor: 'Accessing' stamp: 'BrunoBB 11/25/2015 10:28'!
result
	^result! !

!BpmCodeEvaluationResult methodsFor: 'Updating' stamp: 'BrunoBB 11/25/2015 10:28'!
result: newValue
	result := newValue! !

!BpmCodeEvaluationResult methodsFor: 'other' stamp: 'BrunoBB 11/25/2015 10:30'!
resultNotBoolean

	^(result isKindOf: Boolean) not! !

BpmObject subclass: #BpmCodeFailedEvaluation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmObject subclass: #BpmCodePostExecution
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmCodePostExecution subclass: #BpmCodeNonePostExecution
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmObject subclass: #BpmProcessCategory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

BpmObject subclass: #BpmProcessInstance
	instanceVariableNames: 'definition id processName currentActivities executedActivities transitions subprocesses creator createdTime postExecution startEvent endEvents runningGateways executedGateways userAssignments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmProcessInstance class methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:57'!
definition: aBpmProcessDefinition

	^self definition: aBpmProcessDefinition user: nil! !

!BpmProcessInstance class methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 16:16'!
definition: aBpmProcessDefinition user: aBpmUser

	^super new initialize
		definition: aBpmProcessDefinition;
		creator: aBpmUser;
		processName: aBpmProcessDefinition processName;
		yourself! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
addActivityToPerform: aBpmTaskInstance
	"Add the task <aBpmTaskInstance> to be performed and finished by the receiver"

	^currentActivities add: aBpmTaskInstance! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 12/01/2015 12:01'!
addSubProcess: aBpmSubProcessInstance
	"The receiver add the subprocess <aBpmSubProcessInstance> to it's sub process collection. Set the receiver as the parent process of the process argument <aBpmSubProcessInstance>"

	aBpmSubProcessInstance parentProcess: self.

	^subprocesses add: aBpmSubProcessInstance! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
createdTime
	^createdTime! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
createdTime: newValue
	createdTime := newValue! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
createNewTransition: aBpmTransitionDefinition from: aBpmArtifactInstance
	"The receiver creates a new concrete transition based on the definition <aBpmTransitionDefinition> and this transition has been started from the artifact <aBpmArtifactInstance>"
	| newTransition endArtifact |

	newTransition := BpmTransitionInstance definition: aBpmTransitionDefinition.
	"create the end artifact of the new transition"
	endArtifact := aBpmTransitionDefinition endArtifact createInstanceOn: self.

	newTransition startArtifact: aBpmArtifactInstance; "also add <newTransition> as an outgoing transition to <aBpmArtifactInstance>"
		endArtifact: endArtifact. "also add <newTransition> as an incomming transition to <endArtifact>"

	transitions add: newTransition.

	endArtifact performInitializationOn: self. "the artifact is initialized"

	^newTransition! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
creator
	^creator! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
creator: newValue
	creator := newValue! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
currentActivities
	^currentActivities! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
currentActivities: newValue
	currentActivities := newValue! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
definition
	^definition! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
definition: newValue
	definition := newValue! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
doesNotUnderstand: aMessageDescriptor
	"The receiver overide this method in order to respond to messages that are equal in name to any of it's field name"

	executedActivities
		detect: [:each | each hasFieldNamed: aMessageDescriptor selector] 
		ifNone: [^super doesNotUnderstand: aMessageDescriptor].

	^self getValueOfProcessField: aMessageDescriptor selector asString! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
executedActivities
	^executedActivities! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
executedActivities: newValue
	executedActivities := newValue! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
executedGateways
	^executedGateways! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
executedGateways: newValue
	executedGateways := newValue! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
finalizeGateway: aBpmGatewayInstance
	"The receiver finalize the execution of <aBpmGatewayInstance>.
	Remove the gateway from running gateways dictionary and add it to the executed gateways collection"

	self removeRunningGatewayNamed: aBpmGatewayInstance getDefinitionName.

	executedGateways add: aBpmGatewayInstance! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
finalizeTask: aBpmTaskInstance
	"The receiver finalize the bpm activity <aBpmTaskInstance>"

	currentActivities remove: aBpmTaskInstance ifAbsent: [self throwNoSuchActivityException: aBpmTaskInstance].

	^executedActivities add: aBpmTaskInstance! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 12/01/2015 12:03'!
finalizeWith: aBpmEndEventInstance
	"The receiver is finalized with the end event <aBpmEndEventInstance>"

	^endEvents at: aBpmEndEventInstance getDefinitionName put: aBpmEndEventInstance! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
generateNextTransitionsFrom: aBpmTaskInstance
	"The receiver generate the nexts task to be performed from the finalized task <aBpmTaskInstance>"

	^aBpmTaskInstance getOutTrasitionDefinitions collect: [:transitionDefinition | | newTransition |
			newTransition := self createNewTransition: transitionDefinition from: aBpmTaskInstance.
			newTransition
			].! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
getActiveArtifacts
	"The receiver answer a collection with the current active artifacts"

	^currentActivities! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 16:16'!
getCurrentRunningRoles
	"The receiver answer a collection with all <BpmRole> that have permission to perform any of the current activities that are hold in <currentActivities> collection"! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 16:16'!
getDefinitionName

	^definition processName! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/03/2015 14:09'!
getOrbeonApplication

	^definition orbeonApplication! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 08:30'!
getProcessMatrix

	^BpmRunningTasksMatrix cache at: self getOrbeonApplication app ifAbsent: [self throwNoProcessMatrixException]! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 16:16'!
getRunningGatewayNamed: aString
	"Answer the running gateway named <aString> if none the answer <nil>"

	^runningGateways at: aString ifAbsent: [nil]! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
getValueOfProcessField: fieldName
	"Answer the first value of a field named <fieldName> in the receiver's collection of <executedActivities>.
	The search is performed only in activities that have anOrbeonFormInstance <hasForm>."

	(executedActivities reverse select: [:each | each hasForm]) 
		do: [:each | (each getValueOfFormField: fieldName) ifNotNil: [:value | ^value]].

	^nil

	"#reverse is used because the process can be recursive (can be more than one field value for a given field name) --> we check for the lastest executed transitions"! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 12:33'!
hasFinalized
	"Answer whether or not the receiver has finalized (all tasks has been executed a transition trigger an end event)"

	^endEvents notEmpty! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 16:16'!
hasRunningGatewayNamed: aString
	"Answer whether or not the receiver has a running gateway named <aString>"

	^runningGateways includesKey: aString! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
id
	^id! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
id: newValue
	id := newValue! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 11/29/2015 16:16'!
initialize

	super initialize.

	id := Lag1MwcRandom new integer.
	currentActivities := OrderedCollection new.
	executedActivities := OrderedCollection new.
	transitions := OrderedCollection new.
	subprocesses := OrderedCollection new.
	createdTime := TimeStamp now.
	runningGateways := Dictionary new.
	executedGateways := OrderedCollection new.
	userAssignments := OrderedCollection new.
	endEvents := Dictionary new.! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:52'!
isSubProcess

	^false! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:52'!
isTopProcess

	^false! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:11'!
parentProcess

	self subclassResponsibility! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
postExecution
	^postExecution! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
postExecution: newValue
	postExecution := newValue! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
processName
	^processName! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
processName: newValue
	processName := newValue! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
removeRunningGatewayNamed: aString
	"The receiver remove the gateway named <aString> if not present throw a no running gateway exception"

	^runningGateways removeKey: aString ifAbsent: [self throwGatewayIsNotRunningException: aString]! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
runningGateways
	^runningGateways! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
runningGateways: newValue
	runningGateways := newValue! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
startEvent
	^startEvent! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
startEvent: newValue
	startEvent := newValue! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 11/29/2015 16:16'!
startGateway: aBpmGatewayInstance
	"The receiber start executing in it's context the gateway instance <aBpmGatewayInstance>"

	^runningGateways at: aBpmGatewayInstance getDefinitionName put: aBpmGatewayInstance! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
subprocesses
	^subprocesses! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
subprocesses: newValue
	subprocesses := newValue! !

!BpmProcessInstance methodsFor: 'execeptions' stamp: 'BrunoBB 11/29/2015 16:16'!
throwGatewayIsNotRunningException: aString

	^GatewayIsNotRunningException signal: 'The Gateway named [', aString, '] is not running'! !

!BpmProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/03/2015 14:12'!
throwNoProcessMatrixException

	^NoProcessMatrixException signal: 'No Matrix has been created for process named [', self getDefinitionName, ']'! !

!BpmProcessInstance methodsFor: 'execeptions' stamp: 'BrunoBB 11/29/2015 16:16'!
throwNoSuchActivityException: aBpmTaskInstance

	^NoSuchActivitytException signal: 'No current activity named [', aBpmTaskInstance getDefinitionName, '] in this process'! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
transitions
	^transitions! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
transitions: newValue
	transitions := newValue! !

!BpmProcessInstance methodsFor: 'running' stamp: 'BrunoBB 12/03/2015 14:15'!
triggerStartEvent
	"The receiver start to run it self by finding the outgoing transition of the start event <BpmStartEventInstance>"
	| processMatrix |

	startEvent := BpmStartEventInstance process: self definition: definition startEvent.

	self generateNextTransitionsFrom: startEvent.

	processMatrix := self getProcessMatrix.

	currentActivities do: [:each | processMatrix addTask: each]. "put assignments in the Matrix to taken by users"! !

!BpmProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:16'!
userAssignments
	^userAssignments! !

!BpmProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:16'!
userAssignments: newValue
	userAssignments := newValue! !

BpmProcessInstance subclass: #BpmSubProcessInstance
	instanceVariableNames: 'parentProcess creatorTask creatorEvent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmSubProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 12/01/2015 12:09'!
creatorEvent
	^creatorEvent! !

!BpmSubProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 12/01/2015 12:09'!
creatorEvent: newValue
	creatorEvent := newValue! !

!BpmSubProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 12/01/2015 12:09'!
creatorTask
	^creatorTask! !

!BpmSubProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 12/01/2015 12:09'!
creatorTask: newValue
	creatorTask := newValue! !

!BpmSubProcessInstance methodsFor: 'running' stamp: 'BrunoBB 12/02/2015 14:09'!
finalizeWith: aBpmEndEventInstance
	"The receiver is finalized with the end event <aBpmEndEventInstance>"

	super finalizeWith: aBpmEndEventInstance.

	parentProcess generateNextTransitionsFrom: creatorTask "the parent process resume it's execution"! !

!BpmSubProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:53'!
isSubProcess

	^true! !

!BpmSubProcessInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/29/2015 16:17'!
parentProcess
	^parentProcess! !

!BpmSubProcessInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/29/2015 16:17'!
parentProcess: newValue
	parentProcess := newValue! !

BpmProcessInstance subclass: #BpmTopProcessInstance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmTopProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:53'!
isTopProcess

	^true! !

!BpmTopProcessInstance methodsFor: 'other' stamp: 'BrunoBB 12/01/2015 12:10'!
parentProcess

	^nil! !

BpmObject subclass: #BpmRunningTasksMatrix
	instanceVariableNames: 'orbeonApplication rolesAndProcesses'
	classVariableNames: 'Cache'
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmRunningTasksMatrix class methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 08:30'!
cache

	Cache ifNil: [self initializeCache].

	^Cache! !

!BpmRunningTasksMatrix class methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:02'!
getMatrixForApplicationNamed: aString

	^self cache at: aString ifAbsent: [^NoProcessMatrixException signal: 'No Matrix has been created for process named [', aString, ']']! !

!BpmRunningTasksMatrix class methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 08:30'!
initializeCache

	Cache := Dictionary new! !

!BpmRunningTasksMatrix class methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 09:35'!
newFor: anOrbeonApplication

	^super new initialize
		orbeonApplication: anOrbeonApplication;
		addToCache;
		yourself! !

!BpmRunningTasksMatrix methodsFor: 'task handling' stamp: 'BrunoBB 12/04/2015 09:54'!
addTask: aBpmTaskInstance
	"The receiver create an asignment based on task <aBpmTaskInstance> to be listed as available for the users"

	aBpmTaskInstance getRoles do: [:eachRole | | taskCollection taskAssignment |
		taskCollection := rolesAndProcesses at: eachRole name ifAbsent: [self createSlotFor: eachRole name].
		taskAssignment := aBpmTaskInstance asAssignmentFor: eachRole in: self. "answer <aBpmTaskAssignment>"
		taskCollection add: taskAssignment].! !

!BpmRunningTasksMatrix methodsFor: 'task handling' stamp: 'BrunoBB 12/04/2015 08:29'!
addTasks: collectionOfTasks
	"The receiver create an asignment for each task in <collectionOfTasks> to be listed as available for the users"

	^collectionOfTasks do: [:each | self addTask: each]! !

!BpmRunningTasksMatrix methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 08:29'!
addToCache

	orbeonApplication ifNil: [^self throwExceptionNoOrbeonApplication].

	^self class cache at: orbeonApplication app put: self! !

!BpmRunningTasksMatrix methodsFor: 'task handling' stamp: 'BrunoBB 12/04/2015 08:29'!
createSlotFor: roleName
	"The receiver creates a slot/collection to hold <BpmProcessInstance> where the role named <roleName> is granted.
	This slot/collection can have process with different <BpmProcessDefinition> because the same <BpmRole> can participate in different processes"

	"Inside <RcIdentityBag> create an index by <each.processName> to split by process type"

	^rolesAndProcesses at: roleName put: RcIdentityBag new! !

!BpmRunningTasksMatrix methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 08:29'!
initialize

	super initialize.

	rolesAndProcesses := Dictionary new.! !

!BpmRunningTasksMatrix methodsFor: 'Accessing' stamp: 'BrunoBB 12/04/2015 08:29'!
orbeonApplication
	^orbeonApplication! !

!BpmRunningTasksMatrix methodsFor: 'Updating' stamp: 'BrunoBB 12/04/2015 08:29'!
orbeonApplication: newValue
	orbeonApplication := newValue! !

!BpmRunningTasksMatrix methodsFor: 'task handling' stamp: 'BrunoBB 12/04/2015 10:15'!
remove: aBpmTaskAssignment
	"The receiver remove the task assignment <aBpmTaskAssignment> from it's task collection.
	1- Get the collection for the task role
	2- Remove the object"

	^(rolesAndProcesses at: aBpmTaskAssignment roleName ifAbsent: [self throwExceptionNoSlotFor: aBpmTaskAssignment roleName])
			remove: aBpmTaskAssignment
			ifAbsent: [self throwExceptionTaskAssignmentNotFound]! !

!BpmRunningTasksMatrix methodsFor: 'Accessing' stamp: 'BrunoBB 12/04/2015 08:29'!
rolesAndProcesses
	^rolesAndProcesses! !

!BpmRunningTasksMatrix methodsFor: 'Updating' stamp: 'BrunoBB 12/04/2015 08:29'!
rolesAndProcesses: newValue
	rolesAndProcesses := newValue! !

!BpmRunningTasksMatrix methodsFor: 'task handling' stamp: 'BrunoBB 12/04/2015 08:38'!
sendAssignment: aBpmTaskAssignment from: currentRoleName to: nextRoleName
	"The receiver send in the matrix the process node <aBpmTaskAssignment> from the current role <currentRoleName> to the next role <nextRoleName>.
	This happend when a task is finished by a user and the next tasks are created based on the process definition.
	If <currentRoleName> is equal to <nextRoleName> nothing should happend"
	| currentCollection nextCollection |

	(currentRoleName = nextRoleName) ifTrue: [^aBpmTaskAssignment].

	currentCollection := rolesAndProcesses at: currentRoleName ifAbsent: [self throwExceptionNoSlotFor: currentRoleName].
	nextCollection := rolesAndProcesses at: nextRoleName ifAbsent: [self throwExceptionNoSlotFor: nextRoleName].

	currentCollection remove: aBpmTaskAssignment 
							ifAbsent: [self throwExceptionNoProcessFoundToMoveFrom: currentRoleName to: nextRoleName].

	^nextCollection add: aBpmTaskAssignment! !

!BpmRunningTasksMatrix methodsFor: 'exceptions' stamp: 'BrunoBB 12/04/2015 08:29'!
throwExceptionNoOrbeonApplication

	^NoOrbeonAppException signal: 'A Running Process Matrix must belong to anOrbeonApplication'! !

!BpmRunningTasksMatrix methodsFor: 'exceptions' stamp: 'BrunoBB 12/04/2015 08:29'!
throwExceptionNoProcessFoundToMoveFrom: currentRoleName to: nextRoleName

	^NoProcessToMatrixMoveException signal: 'There is no process to move from [', currentRoleName, '] to [', nextRoleName, ']'! !

!BpmRunningTasksMatrix methodsFor: 'exceptions' stamp: 'BrunoBB 12/04/2015 08:29'!
throwExceptionNoSlotFor: roleName

	^NoMatrixSlotException signal: 'There is no slot/collection for role named [', roleName, ']'! !

!BpmRunningTasksMatrix methodsFor: 'exceptions' stamp: 'BrunoBB 12/04/2015 10:14'!
throwExceptionTaskAssignmentNotFound

	^NoSuchTaskAssignmentException signal: 'The BpmTaskAssignment was not found in the tasks collection'! !

BpmObject subclass: #BpmTaskAssignment
	instanceVariableNames: 'creationDate roleName processName processId taskName taskIsFinished processIsFinished process task user matrix'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmTaskAssignment class methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 09:57'!
newFor: aBpmProcessInstance task: aBpmTaskInstance in: aBpmRunningTasksMatrix

	^super new initialize
		setProcess: aBpmProcessInstance;
		setTask: aBpmTaskInstance;
		matrix: aBpmRunningTasksMatrix;
		yourself! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
creationDate
	^creationDate! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
creationDate: newValue
	creationDate := newValue! !

!BpmTaskAssignment methodsFor: 'other' stamp: 'BrunoBB 12/03/2015 12:13'!
initialize

	super initialize.

	creationDate := TimeStamp now.
	taskIsFinished := false.
	processIsFinished := false.! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/04/2015 09:53'!
matrix
	^matrix! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/04/2015 09:53'!
matrix: newValue
	matrix := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
process
	^process! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 14:06'!
process: newValue
	process := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
processId
	^processId! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
processId: newValue
	processId := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
processIsFinished
	^processIsFinished! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
processIsFinished: newValue
	processIsFinished := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
processName
	^processName! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
processName: newValue
	processName := newValue! !

!BpmTaskAssignment methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:21'!
removeFromMatrix

	^matrix remove: self! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
roleName
	^roleName! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
roleName: newValue
	roleName := newValue! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 14:06'!
setProcess: aBpmProcessInstance
	"The receiver set it process wtih <aBpmProcessInstance> and set related data"

	process := aBpmProcessInstance.
	processId := aBpmProcessInstance id.
	processName := aBpmProcessInstance processName.! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/04/2015 09:42'!
setTask: aBpmTaskInstance
	"The receiver set it task wtih <aBpmTaskInstance> and set related data"

	task := aBpmTaskInstance.
	taskName := aBpmTaskInstance getDefinitionName.! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
task
	^task! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
task: newValue
	task := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
taskIsFinished
	^taskIsFinished! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
taskIsFinished: newValue
	taskIsFinished := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
taskName
	^taskName! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
taskName: newValue
	taskName := newValue! !

!BpmTaskAssignment methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:13'!
user
	^user! !

!BpmTaskAssignment methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:13'!
user: newValue
	user := newValue! !

BpmObject subclass: #BpmTaskLoopCounter
	instanceVariableNames: 'counter iterations'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmTaskLoopCounter methodsFor: 'other' stamp: 'BrunoBB 10/31/2015 10:36'!
addIteration: aBpmArtifactInstance

	counter := counter + 1.

	iterations at: counter put: aBpmArtifactInstance! !

!BpmTaskLoopCounter methodsFor: 'Accessing' stamp: 'BrunoBB 10/31/2015 10:30'!
counter
	^counter! !

!BpmTaskLoopCounter methodsFor: 'Updating' stamp: 'BrunoBB 10/31/2015 10:30'!
counter: newValue
	counter := newValue! !

!BpmTaskLoopCounter methodsFor: 'other' stamp: 'BrunoBB 10/31/2015 10:35'!
initialize

	super initialize.

	counter := 0.
	iterations := Dictionary new.! !

BpmObject subclass: #BpmTransitionInstance
	instanceVariableNames: 'definition startArtifact endArtifact'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmTransitionInstance class methodsFor: 'other' stamp: 'BrunoBB 11/12/2015 11:29'!
definition: aBpmTransitionDefinition

	^super new initialize
		definition: aBpmTransitionDefinition;
		yourself! !

!BpmTransitionInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:55'!
definition
	^definition! !

!BpmTransitionInstance methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 12:55'!
definition: newValue
	definition := newValue! !

!BpmTransitionInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:55'!
endArtifact
	^endArtifact! !

!BpmTransitionInstance methodsFor: 'task connectors' stamp: 'BrunoBB 11/16/2015 18:11'!
endArtifact: aBpmArtifactInstance
	"The receiver set the end artifact with <aBpmArtifactInstance>.
	Also the receiver is an incomming transition of <aBpmArtifactInstance>"

	endArtifact := aBpmArtifactInstance.

	aBpmArtifactInstance addIncommingTransition: self.! !

!BpmTransitionInstance methodsFor: 'other' stamp: 'BrunoBB 11/28/2015 14:41'!
printOn: aStream

	super printOn: aStream.

	aStream nextPutAll: '[', definition name, '] {(', startArtifact printOnType, ')',startArtifact name, '} >> {(', endArtifact printOnType, ')', endArtifact name, '}'.! !

!BpmTransitionInstance methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:55'!
startArtifact
	^startArtifact! !

!BpmTransitionInstance methodsFor: 'task connectors' stamp: 'BrunoBB 11/16/2015 18:11'!
startArtifact: aBpmArtifactInstance
	"The receiver set the start artifact with <aBpmArtifactInstance>.
	Also the receiver is an outgoing transition of <aBpmArtifactInstance>"

	startArtifact := aBpmArtifactInstance.

	aBpmArtifactInstance addOutgoingTransition: self.! !

BpmObject subclass: #BpmUser
	instanceVariableNames: 'name password roles currentAssignments finishedAssignments releasedAssignments'
	classVariableNames: 'Cache'
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmUser class methodsFor: 'other' stamp: 'BrunoBB 11/02/2015 14:51'!
cache

	Cache ifNil: [self initializeCache].

	^Cache! !

!BpmUser class methodsFor: 'other' stamp: 'BrunoBB 11/02/2015 14:51'!
cache: aCollection

	^Cache := aCollection! !

!BpmUser class methodsFor: 'other' stamp: 'BrunoBB 11/22/2015 13:14'!
getUserNamed: aString

	^self cache at: aString ifAbsent: [nil]! !

!BpmUser class methodsFor: 'other' stamp: 'BrunoBB 11/02/2015 14:51'!
initializeCache

	Cache := Dictionary new! !

!BpmUser class methodsFor: 'other' stamp: 'BrunoBB 11/02/2015 15:01'!
newUsername: username password: password 

	^(self username: username password: password)
		addToCache;
		yourself! !

!BpmUser class methodsFor: 'other' stamp: 'BrunoBB 11/02/2015 15:01'!
username: username password: password 

	^super new initialize
		name: username;
		password: password;
		yourself! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 11/22/2015 13:19'!
addRole: aBpmRole

	^roles add: aBpmRole! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 11/02/2015 15:01'!
addToCache

	^self class cache at: name put: self! !

!BpmUser methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:16'!
currentAssignments
	^currentAssignments! !

!BpmUser methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:16'!
currentAssignments: newValue
	currentAssignments := newValue! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:32'!
finalizeAssignment: aBpmTaskAssignment
	"The receiver finalize the assignment <aBpmTaskAssignment>"

	self finalizeTask: aBpmTaskAssignment task! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:30'!
finalizeTask: aBpmTaskInstance
	"The receiver finalize the task <aBpmTaskInstance>"

	aBpmTaskInstance finalize. "remove the task from process current activities and add it to execute activities"! !

!BpmUser methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:16'!
finishedAssignments
	^finishedAssignments! !

!BpmUser methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:16'!
finishedAssignments: newValue
	finishedAssignments := newValue! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 12/03/2015 12:40'!
initialize

	super initialize.

	roles := OrderedCollection new.
	currentAssignments := OrderedCollection new. "aCollection of <BpmTaskAssignment>"
	finishedAssignments := RcIdentityBag new. "aCollection of <BpmTaskAssignment>"
	releasedAssignments := OrderedCollection new. "aCollection of <BpmTaskAssignment>"! !

!BpmUser methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:51'!
name
	^name! !

!BpmUser methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 12:51'!
name: newValue
	name := newValue! !

!BpmUser methodsFor: 'Accessing' stamp: 'BrunoBB 11/01/2015 12:51'!
password
	^password! !

!BpmUser methodsFor: 'Updating' stamp: 'BrunoBB 11/01/2015 12:51'!
password: newValue
	password := newValue! !

!BpmUser methodsFor: 'Accessing' stamp: 'BrunoBB 12/03/2015 12:16'!
releasedAssignments
	^releasedAssignments! !

!BpmUser methodsFor: 'Updating' stamp: 'BrunoBB 12/03/2015 12:16'!
releasedAssignments: newValue
	releasedAssignments := newValue! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 11/22/2015 13:21'!
removeRole: aBpmRole

	^roles remove: aBpmRole ifAbsent: [nil]! !

!BpmUser methodsFor: 'Accessing' stamp: 'BrunoBB 11/22/2015 13:19'!
roles
	^roles! !

!BpmUser methodsFor: 'Updating' stamp: 'BrunoBB 11/22/2015 13:19'!
roles: newValue
	roles := newValue! !

!BpmUser methodsFor: 'other' stamp: 'BrunoBB 12/04/2015 10:33'!
take: aBpmTaskAssignment
	"The receiver take the unassigned task <aBpmTaskAssignment>"

	aBpmTaskAssignment removeFromMatrix. "is not available for other users to take it"

	currentAssignments add: aBpmTaskAssignment.

	aBpmTaskAssignment user: self.! !

BpmObject subclass: #BpmUserOptions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

!BpmProcessDefinition methodsFor: '*orbeonBPMRuntime' stamp: 'BrunoBB 11/29/2015 17:29'!
getProcessInstanceClass

	^BpmProcessInstance! !

!BpmTopProcessDefinition methodsFor: '*orbeonBPMRuntime' stamp: 'BrunoBB 11/29/2015 17:39'!
getProcessInstanceClass

	^BpmTopProcessInstance! !

OrbeonBpmException subclass: #GatewayIsNotRunningException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

OrbeonBpmException subclass: #NoMatrixSlotException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

OrbeonBpmException subclass: #NoProcessMatrixException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

OrbeonBpmException subclass: #NoProcessToMatrixMoveException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

OrbeonBpmException subclass: #NoSuchActivitytException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!

OrbeonBpmException subclass: #NoSuchTaskAssignmentException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OrbeonBPMRuntime'!
